@@ -15,17 +15,24 @@
 #    under the License.
 
 import functools
+import uuid
 
 import six
 from testtools import testcase
 
+import tooz
+
+
+def get_random_uuid():
+    return str(uuid.uuid4()).encode('ascii')
+
 
 def _skip_decorator(func):
     @functools.wraps(func)
     def skip_if_not_implemented(*args, **kwargs):
         try:
             return func(*args, **kwargs)
-        except NotImplementedError as e:
+        except tooz.NotImplemented as e:
             raise testcase.TestSkipped(str(e))
     return skip_if_not_implemented
 
